### R code from vignette source 'lcc_3a.Rnw'

###################################################
### code chunk number 1: lcc_3a.Rnw:20-22
###################################################
options(prompt="> ", continue="+ ", digits=5, width=65, show.signif.stars=T)
par(mfrow=c(1,1))


###################################################
### code chunk number 2: lcc_3a.Rnw:39-40
###################################################
table(dc$cov)


###################################################
### code chunk number 3: lcc_3a.Rnw:105-107
###################################################
require(MASS)
require(nnet)


###################################################
### code chunk number 4: lcc_3a.Rnw:116-118
###################################################
mlm.t.drs <- multinom(cov ~ t + dr.l*ds.l, data=dc)
summary(mlm.t.drs, Wald=T)


###################################################
### code chunk number 5: lcc_3a.Rnw:128-129
###################################################
coefficients(mlm.t.drs)[, c("dr.l", "ds.l")]


###################################################
### code chunk number 6: lcc_3a.Rnw:134-135
###################################################
coefficients(mlm.t.drs)[, "dr.l:ds.l"]


###################################################
### code chunk number 7: lcc_3a.Rnw:142-143
###################################################
summary(mlm.t.drs, Wald=T)$Wald.ratios[, c("dr.l", "ds.l", "dr.l:ds.l")]


###################################################
### code chunk number 8: lcc_3a.Rnw:148-150
###################################################
coefficients(mlm.t.drs)[, "tCp"]
summary(mlm.t.drs, Wald=T)$Wald.ratios[, "tCp"]


###################################################
### code chunk number 9: lcc_3a.Rnw:157-158
###################################################
coefficients(mlm.t.drs)[, c("tCi", "tNt")]


###################################################
### code chunk number 10: lcc_3a.Rnw:165-166
###################################################
head(fitted(mlm.t.drs))


###################################################
### code chunk number 11: lcc_3a.Rnw:173-174
###################################################
dc[1,"cov"]


###################################################
### code chunk number 12: lcc_3a.Rnw:188-190
###################################################
range(dc$dr.l)
range(dc$ds.l)


###################################################
### code chunk number 13: lcc_3a.Rnw:195-201
###################################################
to.predict <- expand.grid(t = levels(dc$t),
                          dr.l = seq(3.4, 9.4, by=.2),
                          ds.l = seq(4.3, 8.8, by=.2))
head(to.predict, 10)
p.fit <- predict(mlm.t.drs, to.predict, type="probs")
head(p.fit, 10)


###################################################
### code chunk number 14: lcc_3a.Rnw:208-211
###################################################
predict(mlm.t.drs, data.frame(t="CA",
                              dr.l=log(1030),
                              ds.l=log(2030)), type="probs")


###################################################
### code chunk number 15: lcc_3a.Rnw:230-233
###################################################
to.graph <- subset(to.predict, (t=="Nt") & (ds.l == 8.7))
str(to.graph)
g.fit <- predict(mlm.t.drs, to.graph, type="probs")


###################################################
### code chunk number 16: lcc_3a.Rnw:240-249
###################################################
plot(c(3.4, 9.4), c(0,1), type="n",
     xlab="Log distance from road",
     ylab="Probability", main="Non-titled lands, far from settlements")
lines(seq(3.4, 9.4, by=.2), g.fit[,"CC"], lty=1, lwd=3, col="green")
lines(seq(3.4, 9.4, by=.2), g.fit[,"CO"], lty=2, lwd=3, col="magenta")
lines(seq(3.4, 9.4, by=.2), g.fit[,"CN"], lty=3, lwd=3, col="red")
text(4, .9, "No deforestation", col="green", pos=4)
text(4, .85, "Partial deforestation", col="magenta", pos=4)
text(4, .8, "Complete deforestation", col="red", pos=4)


###################################################
### code chunk number 17: lcc_3a.Rnw:256-267
###################################################
to.graph <- subset(to.predict, (t=="Ci") & (ds.l == 8.7))
g.fit <- predict(mlm.t.drs, to.graph, type="probs")
plot(c(3.4, 9.4), c(0,1), type="n",
     xlab="Log distance from road",
     ylab="Probability", main="Indigenous lands, far from settlements")
lines(seq(3.4, 9.4, by=.2), g.fit[,"CC"], lty=1, lwd=3, col="green")
lines(seq(3.4, 9.4, by=.2), g.fit[,"CO"], lty=2, lwd=3, col="magenta")
lines(seq(3.4, 9.4, by=.2), g.fit[,"CN"], lty=3, lwd=3, col="red")
text(4, .9, "No deforestation", col="green", pos=4)
text(4, .85, "Partial deforestation", col="magenta", pos=4)
text(4, .8, "Complete deforestation", col="red", pos=4)


###################################################
### code chunk number 18: lcc_3a.Rnw:279-280
###################################################
require(ade4)


###################################################
### code chunk number 19: lcc_3a.Rnw:285-290
###################################################
fits <- data.frame(fitted(mlm.t.drs))
str(fits)
pts <- triangle.plot(fits, scale=F, show.position=F)
points(pts, col=c("green","magenta","red")[as.numeric(dc$cov)])
levels(dc$cov)[1:3]


###################################################
### code chunk number 20: lcc_3a.Rnw:297-298
###################################################
rm(mlm.t.drs, to.predict, p.fit, to.graph, g.fit, fits, pts)


